<?php
/*
Plugin Name: Transactionale
Plugin URI:  https://www.transactionale.com
Description: Transactionale integration for WooCommerce sites.
Version:     2.1.2
Author:      Transactionale Srl
Author URI:  https://www.transactionale.com
License:     GPL-2.0+
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Domain Path: /languages
Text Domain: transactionale

Transactionale is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.
 
Transactionale is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License
along with Transactionale. If not, see {License URI}.
*/

if (!defined('WPINC')) {
    die;
}

define('TR_VERSION', '2.1.2');

include 'functions.php';

register_activation_hook(__FILE__, 'tr_activate');
register_deactivation_hook(__FILE__, 'tr_deactivate');

function tr_show_wc_version_warning()
{
    echo "<div class=\"notice notice-warning is-dismissible\">
        <p>You should install WooCommerce version >= 3.3 to use Transactionale!</p>
    </div>";
}

function tr_missing_terms_warning()
{
    echo "<div class=\"notice notice-warning is-dismissible\">
        <p>
            To use Transactionale, please enable the Terms & Conditions page in <a href=\"admin.php?page=wc-settings&tab=checkout\">WooCommerce Checkout Settings</a>
        </p>
    </div>";
}

function tr_init()
{

    $domain = 'transactionale';
	$locale = apply_filters( 'plugin_locale', get_locale(), $domain );
	// wp-content/languages/plugin-name/plugin-name-de_DE.mo
	load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . $domain . '/' . $domain . '-' . $locale . '.mo' );
	// wp-content/plugins/plugin-name/languages/plugin-name-de_DE.mo
	load_plugin_textdomain( $domain, FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );

    if (!tr_wc_is_v3()) {
        add_action('admin_notices', 'tr_show_wc_version_warning');
        return;
    }

    if (get_option('tr_optin_enabled','1') && !get_option('woocommerce_terms_page_id')) {
        add_action('admin_notices', 'tr_missing_terms_warning');
        add_action('admin_menu', 'tr_plugin_menu');
        add_action('admin_init', 'tr_register_admin_settings');
        add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'tr_add_plugin_settings_woo_commerce_link');
        return;
    }

    add_action('woocommerce_thankyou', 'tr_track_transaction');
    add_action('wp_head', 'tr_snippet_head');
    add_action('woocommerce_single_product_summary', 'tr_view_item');
    add_action('woocommerce_before_shop_loop', 'tr_view_list_init');
    add_action('woocommerce_before_shop_loop_item', 'tr_view_list_item');
    add_action('woocommerce_after_shop_loop', 'tr_view_list_close');
    add_action('woocommerce_cart_contents', 'tr_view_basket');

    // Enable the settings page
    if (is_admin()) {
        add_action('admin_menu', 'tr_plugin_menu');
        add_action('admin_init', 'tr_register_admin_settings');
        add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'tr_add_plugin_settings_link');
    }
    add_action('woocommerce_checkout_after_terms_and_conditions', 'tr_check_optin');
    add_action('woocommerce_edit_account_form', 'tr_check_optin');
    add_action('woocommerce_save_account_details', 'tr_save_optin');
    add_action('woocommerce_checkout_update_order_meta', 'tr_save_optin');
    // add_action('woocommerce_thankyou', 'tr_save_optin');
}

function tr_activate()
{
    $key = get_option('tr_api_key', '');
    if (strlen($key) > 30) {
        $url = 'https://transactionale.com/api/v1/plugins/switchToV2';
        $headers = array(
            "X-Authorization" => $key,
            "Content-Type" => "application/json",
            "Accept" => "application/json",
            "X-Platform" => 'WooCommerce',
            "X-Platform-Version" => tr_get_wc_version(),
            "X-Integration-Version" => TR_VERSION
        );
        $requests_response = Requests::request($url, $headers, array(), 'GET', array());
        update_option('tr_api_key', $requests_response->body);
    } else {
        update_option('tr_api_key', get_option('tr_api_key', ''));
    }

    update_option('tr_enabled', get_option('tr_enabled', '0'));
    update_option('tr_country_code', get_option('tr_country_code', ''));
    update_option('tr_product_format_full', get_option('tr_product_format_full', '1'));
    update_option('tr_touchpoint_web', get_option('tr_touchpoint_web', '2'));
    update_option('tr_touchpoint_id', get_option('tr_touchpoint_id', ''));
    update_option('tr_touchpoint_text', get_option('tr_touchpoint_text', ''));
    update_option('tr_optin_enabled', get_option('tr_optin_enabled', '1'));
}

function tr_deactivate()
{
    update_option('tr_enabled', '0');
}

function tr_plugin_menu()
{
    add_options_page('Transactionale configuration', 'Transactionale', 'manage_options', 'tr_config', 'tr_config_page');
}

function tr_config_page()
{
    require dirname(__FILE__) . '/options.php';
}

function tr_add_plugin_settings_link($links)
{
    $settings_link = '<a href="options-general.php?page=tr_config">Settings</a>';
    if (!get_option('woocommerce_terms_page_id')) {
        $links[] = '<a href="admin.php?page=wc-settings&tab=checkout">Woo commerce Checkout Seetting</a>';
    }
    array_unshift($links, $settings_link);
    return $links;
}

function tr_add_plugin_settings_woo_commerce_link($links)
{

    $links[] = '<a href="admin.php?page=wc-settings&tab=checkout">WooCommerce Checkout Settings</a>';
    //array_unshift($links, $settings_link);  
    return $links;
}

function tr_register_admin_settings()
{
    register_setting('tr-config-group', 'tr_enabled', 'tr_sanitize_tr_enabled');
    register_setting('tr-config-group', 'tr_api_key', 'tr_sanitize_api_key');
    register_setting('tr-config-group', 'tr_country_code', 'tr_sanitize_country_code');
    register_setting('tr-config-group', 'tr_product_format_full', 'tr_sanitize_product_format_full');
    register_setting('tr-config-group', 'tr_touchpoint_web', 'tr_sanitize_touchpoint_type');
    register_setting('tr-config-group', 'tr_touchpoint_id', 'tr_sanitize_touchpoint_id');
    register_setting('tr-config-group', 'tr_touchpoint_text', 'tr_sanitize_touchpoint_text');
    register_setting('tr-config-group', 'tr_optin_enabled', 'tr_sanitize_optin_enabled');
}

/*** Validation callbacks ****/

function tr_sanitize_api_key($input)
{
    $input = trim($input);
    if (!preg_match('/^[\w\d]{3,10}$/', $input)) {
        add_settings_error('tr_api_key', 'tr_api_key', 'Invalid Auth Key', 'error');
    }
    return $input;
}

function tr_sanitize_country_code($input)
{
    $input = strtolower(trim($input));

    if (!preg_match('/^[\w]{2}$/', $input)) {
        add_settings_error('tr_country_code', 'tr_country_code', 'Invalid country code', 'error');
    }
    return $input;
}

function tr_sanitize_tr_enabled($input)
{
    $input = (string)intval(trim($input));
    return $input;
}

function tr_sanitize_product_format_full($input)
{
    $input = (string)intval(trim($input));
    return $input;
}

function tr_sanitize_touchpoint_type($input)
{
    $input = (string)intval(trim($input));
    return $input;
}

function tr_sanitize_touchpoint_id($input)
{
    if (!$input) {
        return '';
    }

    $input = (int)intval(trim($input));
    return $input;
}

function tr_sanitize_touchpoint_text($input)
{
    return trim($input);
}

function tr_sanitize_optin_enabled($input)
{
    $input = (string)intval(trim($input));
    return $input;
}

tr_init();